@@ -17,11 +17,13 @@ class Gates(Hilbert):
         Gates.__qubits_number = qubits_number
         Gates.__first_left = first_left
 
-    def Matrix(self, input):
+    def Matrix(self, input, adjoint = False):
         if(self.getCuda()):
             M = cp.array(input)
         else:
             M = sp.Matrix(input)
+        if(adjoint):
+            M = M.transpose().conjugate()
         return M
 
     def ID(self):
@@ -36,6 +38,14 @@ class Gates(Hilbert):
         M = self.Matrix([[0, 0], [0, 1]])  # |1><1|
         return M
 
+    def L0(self):
+        M = self.Matrix([[0, 1], [0, 0]])  # |0><1|
+        return M
+
+    def L1(self):
+        M = self.Matrix([[0, 0], [1, 0]])  # |1><0|
+        return M
+
     def X(self, target):
         M = self.Matrix([[0, 1], [1, 0]])
         list = self.getOrdListSimpleGate(target, M)
@@ -60,8 +70,8 @@ class Gates(Hilbert):
         operator = self.kronProduct(list)
         return operator
 
-    def S(self, target):
-        M = self.Matrix([[1, 0], [0, 1j]])  # sqrt(Z)
+    def S(self, target, adjoint = False):
+        M = self.Matrix([[1, 0], [0, 1j]], adjoint)  # sqrt(Z)
         list = self.getOrdListSimpleGate(target, M)
         operator = self.kronProduct(list)
         return operator
@@ -131,7 +141,7 @@ class Gates(Hilbert):
         return operator
 
     def CX(self, control, target):
-        M = self.Matrix([[0, 1], [1, 0]]) # X
+        M = self.Matrix([[0, 1], [1, 0]])  # X
         list1,list2 = self.getOrdListCtrlGate(control, target, M)
         operator = self.kronProduct(list1) + self.kronProduct(list2)
         return operator
@@ -151,6 +161,24 @@ class Gates(Hilbert):
         operator = self.kronProduct(list1) + self.kronProduct(list2)
         return operator
 
+    def CV(self, control, target, adjoint = False):
+        M = (1j+1)/2*self.Matrix([[1, -1j], [-1j, 1]], adjoint)  # sqrt(X) ou sqrt(NOT)
+        list1, list2 = self.getOrdListCtrlGate(control, target, M)
+        operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return operator
+
+    def CS(self, control, target, adjoint = False):
+        M = self.Matrix([[1, 0], [0, 1j]], adjoint)  # sqrt(Z)
+        list1, list2 = self.getOrdListCtrlGate(control, target, M)
+        operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return operator
+
+    def CT(self, control, target, adjoint = False):
+        M = self.Matrix([[1, 0], [0, (1+1j)/sqrt(2)]], adjoint)  # sqrt(S)
+        list1, list2 = self.getOrdListCtrlGate(control, target, M)
+        operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return operator
+
     def CRX(self, control, target, theta):
         M = self.Matrix([[cos(theta/2), -1j*sin(theta/2)],
                     [-1j*sin(theta/2), cos(theta/2)]])
@@ -209,6 +237,12 @@ class Gates(Hilbert):
         operator = self.kronProduct(list1) + self.kronProduct(list2)
         return operator
 
+    def Fredkin(self, control, target1, target2):
+        #Gate = self.Matrix([[0, 1], [1, 0]])-self.ID()
+        #list1,list2 = self.getOrdListCtrl2Gate(control1, control2, target, Gate)
+        #operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return None
+
     def SWAP(self):
         M = self.Matrix([[1, 0, 0, 0], [0, 0, 1, 0],
                     [0, 1, 0, 0], [0, 0, 0, 1]])
